# Generic dataflow for 1, 2, 3 or 4 line address block.
def name_block(profile, business, *lines)
	business = false unless business.kind_of? TrueClass
	name = address1 = address2 = address3 = ''

	if (profile.to_s[2,10] == 'Individual')
		# Decide if profile's business or personal information should be used.
		if (business and !profile.business_name.strip.empty?)
			# Use business information.
			name = profile.business_name
			if ((profile.business_address.strip.empty?) and (profile.business_address2.strip.empty?))
				address1 = profile.address
				address2 = 'Apt. #' + profile.apartment_number unless profile.apartment_number.strip.empty?
				address3 = (profile.city.strip.empty? ? '' : profile.city + ', ') + profile.state + ' ' + profile.zip
			else
				address1 = profile.business_address
				address2 = profile.business_address2
				address3 = (profile.business_city.strip.empty? ? '' : profile.business_city + ', ') + profile.business_state + ' ' + profile.business_zip
			end
		else
			# Using personal information.
			name = profile.first_name + ' ' + profile.middle_initial + ' ' + profile.last_name + ' ' + profile.suffix
			address1 = profile.address
			address2 = 'Apt. #' + profile.apartment_number unless profile.apartment_number.strip.empty?
			address3 = (profile.city.strip.empty? ? '' : profile.city + ', ') + profile.state + ' ' + profile.zip
		end
	elsif profile.to_s[2,6] == 'Entity'
		name = profile.name
		address1 = profile.address
		address2 = profile.address2
		address3 = (profile.city.strip.empty? ? '' : profile.city + ', ') + profile.state + ' ' + profile.zip
	elsif profile.to_s[2,8] == 'Preparer'
		# Use Firm name if available and business = true.
		# Use Preparer name if the Preparer is self-employed and business = false.
		if (!profile.firm_name.strip.empty? and ((profile.self_employed.strip.empty?) or (!profile.self_employed.strip.empty? and business)))
			name = profile.firm_name
		else
			name = profile.first_name + ' ' + profile.middle_initial + ' ' + profile.last_name
		end
		address1 = profile.address
		address3 = (profile.city.strip.empty? ? '' : profile.city + ', ') + profile.state + ' ' + profile.zip	
	elsif profile.to_s[2,3] == 'Fcc'
		# Use entity name if available.
		if (profile.applicant_entity_name.strip.empty?)
			name = profile.applicant_first_name + ' ' + profile.applicant_middle_initial + ' ' + profile.applicant_last_name + ' ' + profile.applicant_suffix
		else
			name = profile.applicant_entity_name
		end
		address1 = profile.applicant_address
		address2 = 'P.O. Box ' + profile.applicant_po_box unless profile.applicant_po_box.strip.empty?
		address3 = (profile.applicant_city.strip.empty? ? '' : profile.applicant_city + ', ') + (profile.applicant_state.strip.empty? ? profile.applicant_country : profile.applicant_state) + ' ' + profile.applicant_zip
	else
		return
	end
	
	name = name.squeeze(' ').strip
	address1 = address1.squeeze(' ').strip
	address2 = address2.squeeze(' ').strip
	address3 = address3.squeeze(' ').strip
	
	# Decide what lines are output.
	case lines.length
		when 1
			name += ' ' + address1 + ' ' + address2 + ' ' + address3
			name = name.squeeze(' ').strip
			address1 = address2 = address3 = ''
		when 2
			address1 += ' ' + address2 + ' ' + address3
			address1 = address1.squeeze(' ').strip
			address2 = address3 = ''
		when 3
			address1 += ' ' + address2
			address1 = address1.squeeze(' ').strip
			address2 = address3
			address3 = ''
		when 4
			if (address2.empty?)
				address2 = address3
				address3 = ''
			end
	end

	print lines[0], name if !name.empty?
	print lines[1], address1 if !address1.empty?
	print lines[2], address2 if !address2.empty?
	print lines[3], address3 if !address3.empty?

end

entity = Entity.new
individual = Individual.new

#The box assignments below are samples. Change the box numbers to match the form.

name_block(individual, false, 'box1_1', 'box1_2', 'box1_3', 'box1_4')
name_block(entity, false,  'box1_1', 'box1_2', 'box1_3', 'box1_4')